@@ -273,6 +273,11 @@ class Uplink(NCSInstance):
         self.uplink_type.al_to_al.remote_interface = Leaf(str)
 
 
+class DistNetwork(NCSInstance):
+
+    def initialize_model(self):
+        self.name = Leaf(str)
+
 class Distribution(NCSInstance):
 
     _path = "/config/services/distribution"
@@ -290,7 +295,7 @@ class Distribution(NCSInstance):
         self.fabric = Leaf(str)
 
         self.routing = Container()
-        self.routing.network = LeafList(str)
+        self.routing.network = List(DistNetwork)
 
         # note that because we're only dealing with legacy zones
         # right now, the primary/secondary DLs can be modeled
